# -*- coding: utf-8 -*-
# Generated by Django 1.9.2 on 2016-03-02 11:35
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wazimap', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='geography',
            name='long_name',
            field=models.CharField(db_index=True, max_length=100, null=True),
        ),
    ]
