{% extends 'topics/_base_topics.html' %}

{% block content %}
<section id="topic-overview">
{% include "topics/_question_aside.html" %}    
<h2>Overview</h2>
<p>The ACS asks questions about where Americans work, how they get to work, and how long their commute takes.</p>
<h2>Travel Time to Work</h2>    

<table>
<thead><tr>
<th>Code</th>
<th>Title</th>
</tr></thead>
<tbody>
<tr>
<td>
<strong><a href="{% url 'table_detail' 'B08136' %}">B08136</a></strong><sup>‡</sup>
</td>
<td>Aggregate Travel Time to Work (In Minutes) of Workers by Means of Transportation to Work</td>
</tr>
<tr>
<td>
<strong><a href="{% url 'table_detail' 'B08536' %}">B08536</a></strong><sup>‡</sup>
</td>
<td>Aggregate Travel Time to Work (In Minutes) of Workers by Means of Transportation to Work for Workplace Geography</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08131' %}">B08131</a></strong></td>
<td>Aggregate Travel Time to Work (In Minutes) of Workers by Place of Work-- State and County Level</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08013' %}">B08013</a></strong></td>
<td>Aggregate Travel Time to Work (In Minutes) of Workers by Sex</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08135' %}">B08135</a></strong></td>
<td>Aggregate Travel Time to Work (In Minutes) of Workers by Travel Time to Work</td>
</tr>
<tr>
<td>
<strong><a href="{% url 'table_detail' 'B08532' %}">B08532</a></strong><sup>‡</sup>
</td>
<td>Means of Transportation to Work by Time Arriving at Work From Home for Workplace Geography</td>
</tr>
<tr>
<td>
<strong><a href="{% url 'table_detail' 'B08132' %}">B08132</a></strong><sup>‡</sup>
</td>
<td>Means of Transportation to Work by Time Leaving Home to Go to Work</td>
</tr>
<tr>
<td>
<strong><a href="{% url 'table_detail' 'B08134' %}">B08134</a></strong><sup>‡</sup>
</td>
<td>Means of Transportation to Work by Travel Time to Work</td>
</tr>
<tr>
<td>
<strong><a href="{% url 'table_detail' 'B08534' %}">B08534</a></strong><sup>‡</sup>
</td>
<td>Means of Transportation to Work by Travel Time to Work for Workplace Geography</td>
</tr>
<tr>
<td>
<strong><a href="{% url 'table_detail' 'B08011' %}">B08011</a></strong><sup>‡</sup>
</td>
<td>Sex of Workers by Time Leaving Home to Go to Work</td>
</tr>
<tr>
<td>
<strong><a href="{% url 'table_detail' 'B08012' %}">B08012</a></strong><sup>‡</sup>
</td>
<td>Sex of Workers by Travel Time to Work</td>
</tr>
<tr>
<td>
<strong><a href="{% url 'table_detail' 'B08412' %}">B08412</a></strong><sup>‡</sup>
</td>
<td>Sex of Workers by Travel Time to Work for Workplace Geography</td>
</tr>
<tr>
<td>
<strong><a href="{% url 'table_detail' 'B08602' %}">B08602</a></strong><sup>‡</sup>
</td>
<td>Time Arriving at Work From Home for Workplace Geography</td>
</tr>
<tr>
<td>
<strong><a href="{% url 'table_detail' 'B08302' %}">B08302</a></strong><sup>‡</sup>
</td>
<td>Time Leaving Home to Go to Work</td>
</tr>
<tr>
<td>
<strong><a href="{% url 'table_detail' 'B08303' %}">B08303</a></strong><sup>‡</sup>
</td>
<td>Travel Time to Work</td>
</tr>
<tr>
<td>
<strong><a href="{% url 'table_detail' 'B08603' %}">B08603</a></strong><sup>‡</sup>
</td>
<td>Travel Time to Work for Workplace Geography</td>
</tr>
</tbody>
<tfoot>
         <tr class="help-text">
            <td colspan="2">
                <sup>‡</sup>Table also available in "collapsed" version: change "B" to "C" for table code.<br>
            </td>
        </tr>
    </tfoot>
</table>

<h2>Place of Work</h2>

<p>Tables about place of work can be used to determine to some extent how far people travel for their jobs. Columns do not refer to time or distance, but rather to whether or not people work in the same geography that they live in.</p>

<table>
<thead><tr>
<th>Code</th>
<th>title</th>
</tr></thead>
<tbody>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08007' %}">B08007</a><sup>‡</sup></strong></td>
<td>Sex of Workers by Place of Work--State and County Level</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08008' %}">B08008</a></strong></td>
<td>Sex of Workers by Place of Work--Place Level</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08009' %}">B08009</a></strong></td>
<td>Sex of Workers by Place of Work--Minor Civil Division Level for 12 Selected States (CT, ME, MA, MI, MN, NH, NJ, NY, PA, RI, VT, WI)</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08016' %}">B08016</a><sup>‡</sup></strong></td>
<td>Place of Work for Workers 16 Years and Over--Metropolitan Statistical Area Level</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08017' %}">B08017</a><sup>‡</sup></strong></td>
<td>Place of Work for Workers 16 Years and Over--Micropolitan Statistical Area Level</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08018' %}">B08018</a><sup>‡</sup></strong></td>
<td>Place of Work for Workers 16 Years and Over--not Metropolitan or Micropolitan Statistical Area Level</td>
</tr>
</tbody>
<tfoot>
         <tr class="help-text">
            <td colspan="2">
                <sup>‡</sup>Table also available in "collapsed" version: change "B" to "C" for table code.<br>
            </td>
        </tr>
    </tfoot>
</table>

<h2>Means of transportation to work</h2>
<p>At first glance, there appear to be a surprising number of tables about how Americans get to work. Note that this is partially because for most cross-tabulations, there are two versions of the table: one where the numbers represent people living in the selected geography, and another which represents people working in the selected geography.</p>
<p>Here are the basic answers available about means of transportation to work. In some tables, some of these answers are collapsed into fewer rows:</p>
<ul>
<li>Car, truck, or van:
    <ul>
<li>Drove alone</li>
     <li>Carpooled
     <ul>
<li>In 2-person carpool</li>
       <li>In 3-person carpool</li>
       <li>In 4-or-more-person carpool</li>
     </ul>
</li>
    </ul>
</li>
    <li>
   Public transportation (excluding taxicab):
   <ul>
<li>Bus or trolley bus</li>
    <li>Streetcar or trolley car (carro publico in Puerto Rico)</li>
    <li>Subway or elevated</li>
    <li>Railroad</li>
    <li>Ferryboat</li>
   </ul>
</li>
   <li>Bicycle</li>
   <li>Walked</li>
   <li>Taxicab, motorcycle, or other means</li>
   <li>Worked at home</li>
</ul><table>
<thead><tr>
<th>Code</th>
<th>Title</th>
</tr></thead>
<tbody>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08006' %}">B08006</a><sup>‡</sup></strong></td>
<td>Sex of Workers by Means of Transportation to Work</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08101' %}">B08101</a><sup>‡</sup></strong></td>
<td>Means of Transportation to Work by Age</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08103' %}">B08103</a></strong></td>
<td>Median Age by Means of Transportation to Work</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08105' %}">B08105</a><sup>ª‡</sup></strong></td>
<td>Means of Transportation to Work (racial iterations)</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08111' %}">B08111</a><sup>‡</sup></strong></td>
<td>Means of Transportation to Work by Citizenship Status</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08113' %}">B08113</a><sup>‡</sup></strong></td>
<td>Means of Transportation to Work by Language Spoken at Home and Ability to Speak English</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08119' %}">B08119</a><sup>‡</sup></strong></td>
<td>Means of Transportation to Work by Workers' Earnings</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08121' %}">B08121</a></strong></td>
<td>Median Earnings by Means of Transportation to Work</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08122' %}">B08122</a><sup>‡</sup></strong></td>
<td>Means of Transportation to Work by Poverty Status in the Past 12 Months</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08124' %}">B08124</a><sup>‡</sup></strong></td>
<td>Means of Transportation to Work by Occupation</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08126' %}">B08126</a><sup>‡</sup></strong></td>
<td>Means of Transportation to Work by Industry</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08128' %}">B08128</a><sup>‡</sup></strong></td>
<td>Means of Transportation to Work by Class of Worker</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08130' %}">B08130</a><sup>‡</sup></strong></td>
<td>Means of Transportation to Work by Place of Work--State and County Level</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08132' %}">B08132</a><sup>‡</sup></strong></td>
<td>Means of Transportation to Work by Time Leaving Home to Go to Work</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08134' %}">B08134</a><sup>‡</sup></strong></td>
<td>Means of Transportation to Work by Travel Time to Work</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08136' %}">B08136</a><sup>‡</sup></strong></td>
<td>Aggregate Travel Time to Work (In Minutes) of Workers by Means of Transportation to Work</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08137' %}">B08137</a><sup>‡</sup></strong></td>
<td>Means of Transportation to Work by Tenure</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08141' %}">B08141</a><sup>‡</sup></strong></td>
<td>Means of Transportation to Work by Vehicles Available</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08301' %}">B08301</a><sup>‡</sup></strong></td>
<td>Means of Transportation to Work</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08406' %}">B08406</a><sup>‡</sup></strong></td>
<td>Sex of Workers by Means of Transportation to Work for Workplace Geography</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08501' %}">B08501</a><sup>‡</sup></strong></td>
<td>Means of Transportation to Work by Age for Workplace Geography</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08503' %}">B08503</a></strong></td>
<td>Median Age by Means of Transportation to Work for Workplace Geography</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08505' %}">B08505</a><sup>ª‡</sup></strong></td>
<td>Means of Transportation to Work for Workplace Geography (racial iterations)</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08511' %}">B08511</a><sup>‡</sup></strong></td>
<td>Means of Transportation to Work by Citizenship Status for Workplace Geography</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08513' %}">B08513</a><sup>‡</sup></strong></td>
<td>Means of Transportation to Work by Language Spoken at Home and Ability to Speak English for Workplace Geography</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08519' %}">B08519</a><sup>‡</sup></strong></td>
<td>Means of Transportation to Work by Workers' Earnings for Workplace Geography</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08521' %}">B08521</a></strong></td>
<td>Median Earnings by Means of Transportation to Work for Workplace Geography</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08522' %}">B08522</a><sup>‡</sup></strong></td>
<td>Means of Transportation to Work by Poverty Status in the Past 12 Months for Workplace Geography</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08524' %}">B08524</a><sup>‡</sup></strong></td>
<td>Means of Transportation to Work by Occupation for Workplace Geography</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08526' %}">B08526</a><sup>‡</sup></strong></td>
<td>Means of Transportation to Work by Industry for Workplace Geography</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08528' %}">B08528</a><sup>‡</sup></strong></td>
<td>Means of Transportation to Work by Class of Worker for Workplace Geography</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08532' %}">B08532</a><sup>‡</sup></strong></td>
<td>Means of Transportation to Work by Time Arriving at Work From Home for Workplace Geography</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08534' %}">B08534</a><sup>‡</sup></strong></td>
<td>Means of Transportation to Work by Travel Time to Work for Workplace Geography</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08536' %}">B08536</a><sup>‡</sup></strong></td>
<td>Aggregate Travel Time to Work (In Minutes) of Workers by Means of Transportation to Work for Workplace Geography</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08537' %}">B08537</a><sup>‡</sup></strong></td>
<td>Means of Transportation to Work by Tenure for Workplace Geography</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08541' %}">B08541</a><sup>‡</sup></strong></td>
<td>Means of Transportation to Work by Vehicles Available for Workplace Geography</td>
</tr>
<tr>
<td><strong><a href="{% url 'table_detail' 'B08601' %}">B08601</a><sup>‡</sup></strong></td>
<td>Means of Transportation to Work for Workplace Geography</td>
</tr>
</tbody>
<tfoot>
        <tr class="help-text">
            <td colspan="2">
                <sup>†</sup>Also available in <a href="{% url 'topic_detail' 'race-latino' %}#topic-elsewhere">racial iterations</a>.<br>
                <sup>‡</sup>Table also available in "collapsed" version: change "B" to "C" for table code.<br>
                <sup>ª</sup>No basic table is offered–only <a href="{% url 'topic_detail' 'race-latino' %}#topic-elsewhere">racial iteration</a> tables.<br>
            </td>
        </tr>
    </tfoot>
</table>

</section>
{% endblock %}


